summaryrefslogtreecommitdiff
path: root/package/inc/EncryptedDataHeader.hxx
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2003-09-11 09:13:44 +0000
committerKurt Zenker <kz@openoffice.org>2003-09-11 09:13:44 +0000
commit594d4f450641e724f9f24c2ea272830a0dab5c51 (patch)
tree02cdb55e6217dc4e786d3f97a68f5e058fb08a98 /package/inc/EncryptedDataHeader.hxx
parent7d14b305bd8251a6119d611e03f797a42346217c (diff)
INTEGRATION: CWS mav05 (1.1.56); FILE MERGED
2003/07/21 14:14:19 mav 1.1.56.1: #i15929# include MediaType in raw stream header, and other fixes
Diffstat (limited to 'package/inc/EncryptedDataHeader.hxx')
-rw-r--r--package/inc/EncryptedDataHeader.hxx8
1 files changed, 5 insertions, 3 deletions
diff --git a/package/inc/EncryptedDataHeader.hxx b/package/inc/EncryptedDataHeader.hxx
index e8069e146b0e..2e303e1db2df 100644
--- a/package/inc/EncryptedDataHeader.hxx
+++ b/package/inc/EncryptedDataHeader.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: EncryptedDataHeader.hxx,v $
*
- * $Revision: 1.1 $
+ * $Revision: 1.2 $
*
- * last change: $Author: mtg $ $Date: 2001-11-15 20:04:25 $
+ * last change: $Author: kz $ $Date: 2003-09-11 10:13:44 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -74,12 +74,14 @@
Salt length 2 bytes
IV length 2 bytes
Digest length 2 bytes
+ MediaType length 2 bytes
Salt content X bytes
IV content X bytes
digest content X bytes
+ MediaType X bytes
*/
const sal_uInt32 n_ConstHeader = 0x0502474dL; // "MG\002\005"
-const sal_Int32 n_ConstHeaderSize = 20; // + salt length + iv length + digest length
+const sal_Int32 n_ConstHeaderSize = 22; // + salt length + iv length + digest length + mediatype length
const sal_Int16 n_ConstCurrentVersion = 1;
#endif